@@ -15,6 +15,15 @@
 #include "config.h"
 #include <linc/linc.h>
 
+#ifdef LINC_SSL_SUPPORT
+
+#include <openssl/ssl.h>
+#include <openssl/bio.h>
+extern SSL_METHOD *linc_ssl_method;
+extern SSL_CTX *linc_ssl_ctx;
+
+#endif /* LINC_SSL_SUPPORT */
+
 /*
  * Really raw internals, exported for the tests
  */
@@ -56,22 +65,13 @@ struct _LincWatch {
 	GSource *linc_source;
 };
 
-#ifdef LINC_SSL_SUPPORT
-
-#include <openssl/ssl.h>
-#include <openssl/bio.h>
-extern SSL_METHOD *linc_ssl_method;
-extern SSL_CTX *linc_ssl_ctx;
-
-#endif /* LINC_SSL_SUPPORT */
-
 #define LINC_ERR_CONDS (G_IO_ERR|G_IO_HUP|G_IO_NVAL)
 #define LINC_IN_CONDS  (G_IO_PRI|G_IO_IN)
 
 struct sockaddr *linc_protocol_get_sockaddr (const LINCProtocolInfo *proto,
 					     const char             *hostname,
 					     const char             *service,
-					     socklen_t              *saddr_len);
+					     LincSockLen            *saddr_len);
 
 gboolean         linc_protocol_get_sockinfo (const LINCProtocolInfo *proto,
 					     const struct sockaddr  *saddr,
@@ -80,7 +80,16 @@ gboolean         linc_protocol_get_sockinfo (const LINCProtocolInfo *proto,
 
 gboolean         linc_protocol_is_local     (const LINCProtocolInfo  *proto,
 					     const struct sockaddr   *saddr,
-					     socklen_t                saddr_len);
+					     LincSockLen              saddr_len);
+
+void             linc_protocol_destroy_cnx  (const LINCProtocolInfo  *proto,
+					     int                      fd,
+					     const char              *host,
+					     const char              *service);
+
+void             linc_protocol_destroy_addr (const LINCProtocolInfo  *proto,
+					     int                      fd,
+					     struct sockaddr         *saddr);
 
 LincWatch       *linc_io_add_watch_fd       (int                     fd,
 					     GIOCondition            condition,
